==> antiright-2.99.6.tar.bz2: antiright/gtkshell/options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern unsigned int gsh_rows;
extern GtkWidget *gsh_button;

void
gsh_count(int argc, int *counter)
{
 (*counter)++;
 assert((*counter) <= argc);
}

void
gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter)
{
	gsh_check_row();
 	switch (argv[(*counter)][1])
 	{
		case 'a':
			gsh_handle_add_arguments(
				argc, 
				argv, 
				counter);
			break;
		case 'd':	
			gsh_handle_dialog_arguments(
				argc, 
				argv, 
				counter);
			break;
        case 'h':
            g_printerr("Read the source code.\n");
            exit(1);
            break;
		case 'o':
			gsh_handle_option_arguments(
				argc, 
				argv, 
				counter);
			break;
		default:
			g_printerr("%s:  undefined\n", argv[(*counter)]);
			break;
	}
}

==> antiright-2.99.7.tar.bz2: antiright/gtkshell/options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_count(int argc, int *counter)
{
 (*counter)++;
 assert((*counter) <= argc);
}

void
gsh_handle_switch_arguments(struct GSH *gsh, int argc, char **argv, int *counter)
{
	gsh_check_row(gsh);
 	switch (argv[(*counter)][1])
 	{
		case 'a':
			gsh_handle_add_arguments(gsh,
				argc, 
				argv, 
				counter);
			break;
		case 'd':	
			gsh_handle_dialog_arguments(gsh,
				argc, 
				argv, 
				counter);
			break;
        case 'h':
            g_printerr("Read the source code.\n");
            exit(1);
            break;
		case 'o':
			gsh_handle_option_arguments(gsh,
				argc, 
				argv, 
				counter);
			break;
		default:
			g_printerr("%s:  %s undefined\n", argv[0], argv[(*counter)]);
			break;
	}
}
